@@ -23,9 +23,10 @@ from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
 from ai.h2o.sparkling.ml.params.HasDeprecatedVariableImportancesOnMOJO import HasDeprecatedVariableImportancesOnMOJO
+from ai.h2o.sparkling.ml.params.HasDeprecatedAutoencoderOnMOJO import HasDeprecatedAutoencoderOnMOJO
 
 
-class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasDeprecatedVariableImportancesOnMOJO):
+class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasDeprecatedVariableImportancesOnMOJO, HasDeprecatedAutoencoderOnMOJO):
 
     @staticmethod
     def createFromMojo(pathToMojo, settings=H2OMOJOSettings.default()):
@@ -225,11 +226,6 @@ class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         return value
 
 
-    def getAutoencoder(self):
-        value = self._java_obj.getAutoencoder()
-        return value
-
-
     def getUseAllFactorLevels(self):
         value = self._java_obj.getUseAllFactorLevels()
         return value
