@@ -34,6 +34,12 @@ class H2OAlgorithmMOJOParams(H2OBaseMOJOParams):
         "Column containing additional prediction details, its content depends on the model type.",
         H2OTypeConverters.toString())
 
+    withDetailedPredictionCol = Param(
+        Params._dummy(),
+        "withDetailedPredictionCol",
+        "Enables or disables generating additional prediction column, but with more details",
+        H2OTypeConverters.toBoolean())
+
     withContributions = Param(
         Params._dummy(),
         "withContributions",
@@ -73,6 +79,11 @@ class H2OAlgorithmMOJOParams(H2OBaseMOJOParams):
     def getDetailedPredictionCol(self):
         return self.getOrDefault(self.detailedPredictionCol)
 
+    def getWithDetailedPredictionCol(self):
+        warnings.warn("The method will be removed without a replacement in the version 3.36."
+                      "Detailed prediction columns is always enabled.", DeprecationWarning)
+        return True
+
     def getWithContributions(self):
         return self.getOrDefault(self.withContributions)
 
@@ -80,8 +91,6 @@ class H2OAlgorithmMOJOParams(H2OBaseMOJOParams):
         return self.getOrDefault(self.featuresCols)
 
     def getNamedMojoOutputColumns(self):
-        warnings.warn("The method will be removed without replacement in the version 3.40."
-        "Named output columns will be always used.", DeprecationWarning)
         return self.getOrDefault(self.namedMojoOutputColumns)
 
     def getWithLeafNodeAssignments(self):
